[PATCH 2/2] board: xilinx: zynqmp: use reset assert helper in reset_cpu()

Akshay Belsare <[email protected]>
Newsgroups org.u-boot-project.lists.u-boot
Message-ID <[email protected]>
reset_cpu() currently invokes xilinx_pm_request(PM_RESET_ASSERT, ...)
directly to assert a system reset. Switch it to use
zynqmp_pm_reset_assert(), matching the approach used by
reset-zynqmp.c and centralizing the firmware interaction behind a
common helper.
 
Keep the IS_ENABLED(CONFIG_ZYNQMP_FIRMWARE) early return unchanged so
the reset path continues to compile out when firmware support is not
enabled.

Signed-off-by: Akshay Belsare <[email protected]>
---
 board/xilinx/zynqmp/zynqmp.c | 7 +++----
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/board/xilinx/zynqmp/zynqmp.c b/board/xilinx/zynqmp/zynqmp.c
index 5d13881f3ec..c7464b493c5 100644
--- a/board/xilinx/zynqmp/zynqmp.c
+++ b/board/xilinx/zynqmp/zynqmp.c
@@ -288,13 +288,12 @@ void reset_cpu(void)
 		return;
 	}
 
 	/* In case of !CONFIG_ZYNQMP_FIRMWARE the call to 'xilinx_pm_request()'
 	 * will be removed by the compiler due to the early return.
 	 * If CONFIG_ZYNQMP_FIRMWARE is defined in SPL 'xilinx_pm_request()'
 	 * will send command over IPI and requires pmufw to be present.
 	 */
-	xilinx_pm_request(PM_RESET_ASSERT, ZYNQMP_PM_RESET_SOFT,
-			  PM_RESET_ACTION_ASSERT, 0, 0, 0, 0, NULL);
+	zynqmp_pm_reset_assert(ZYNQMP_PM_RESET_SOFT, PM_RESET_ACTION_ASSERT);
 }
 #endif
 
@@ -288,13 +288,12 @@ void reset_cpu(void)
 	}
 
-	/* In case of !CONFIG_ZYNQMP_FIRMWARE the call to 'xilinx_pm_request()'
+	/* In case of !CONFIG_ZYNQMP_FIRMWARE the call to 'zynqmp_pm_reset_assert()'
 	 * will be removed by the compiler due to the early return.
@@ -288,13 +288,12 @@ void reset_cpu(void)
 	 * will be removed by the compiler due to the early return.
-	 * If CONFIG_ZYNQMP_FIRMWARE is defined in SPL 'xilinx_pm_request()'
+	 * If CONFIG_ZYNQMP_FIRMWARE is defined in SPL 'zynqmp_pm_reset_assert()'
 	 * will send command over IPI and requires pmufw to be present.
 	 */
-- 
2.34.1
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.